@@ -22,7 +22,7 @@ COLOR_INDEX = (
     '00FF99CC', '00CC99FF', '00FFCC99', '003366FF', '0033CCCC', #45-49
     '0099CC00', '00FFCC00', '00FF9900', '00FF6600', '00666699', #50-54
     '00969696', '00003366', '00339966', '00003300', '00333300', #55-59
-    '00993300', '00993366', '00333399', 'System Foreground', 'System Background' #60-64
+    '00993300', '00993366', '00333399', '00333333', 'System Foreground', 'System Background' #60-64
 )
 
 BLACK = COLOR_INDEX[0]
