@@ -21,6 +21,7 @@ from openpyxl.writer.comments import CommentWriter
 from .relations import write_rels
 from .worksheet import (
     write_autofilter,
+    write_datavalidation,
     write_cell,
     write_cols,
     write_format,
@@ -125,9 +126,15 @@ class DumpWorksheet(Worksheet):
                             xf.write(r)
                     except GeneratorExit:
                         pass
+                if self.protection.sheet:
+                    prot = Element('sheetProtection', dict(self.protection))
+                    xf.write(prot)
                 af = write_autofilter(self)
                 if af is not None:
                     xf.write(af)
+                dv = write_datavalidation(self)
+                if dv is not None:
+                    xf.write(dv)
                 if self._comments:
                     comments = Element('legacyDrawing', {'{%s}id' % REL_NS: 'commentsvml'})
                     xf.write(comments)
